import replaceInFile from "replace-in-file";
import { readFileAsJson } from "../../shared/readFileAsJson.js";
async function updateLocalFiles({
  description,
  npmAuthor,
  owner,
  repository,
  title
}) {
  const existingPackage = await readFileAsJson(
    "./package.json"
  );
  const replacements = [
    [/Template TypeScript Node Package/g, title],
    [/JoshuaKGoldberg/g, owner],
    [/template-typescript-node-package/g, repository],
    [/\/\*\n.+\*\/\n\n/gs, ``, ".eslintrc.cjs"],
    [/"author": ".+"/g, `"author": "${npmAuthor}"`, "./package.json"],
    [/"bin": ".+\n/g, ``, "./package.json"],
    [/"hydrate:test": ".+\n/g, ``, "./package.json"],
    [/"setup:test": ".*/g, ``, "./package.json"],
    [/"setup": ".*/g, ``, "./package.json"],
    [/## Explainer.*## Usage/gs, `## Usage`, "./README.md"],
    [/\n## The .+ Script.*$/gs, "", "./.github/DEVELOPMENT.md"],
    [`,
		["src/setup/*.json"`, ``, "./cspell.json"],
    [`		"src/hydrate/index.ts",
`, ``, "./knip.jsonc"],
    [`		"src/setup/index.ts",
`, ``, "./knip.jsonc"],
    [`		"ignoreDependencies": ["c8"],
`, ``, "./knip.jsonc"],
    [
      `["src/index.ts!", "script/setup*.js"]`,
      `"src/index.ts!"`,
      "./knip.jsonc"
    ],
    [`["src/**/*.ts!", "script/**/*.js"]`, `"src/**/*.ts!"`, "./knip.jsonc"]
  ];
  if (existingPackage.description) {
    replacements.push([
      new RegExp(existingPackage.description, "g"),
      description
    ]);
  }
  if (existingPackage.version) {
    replacements.push([
      new RegExp(`"version": "${existingPackage.version}"`, "g"),
      `"version": "0.0.0"`,
      "./package.json"
    ]);
  }
  for (const [from, to, files = ["./.github/**/*", "./*.*"]] of replacements) {
    try {
      await replaceInFile({ files, from, to });
    } catch (error) {
      throw new Error(
        `Failed to replace ${from.toString()} with ${to} in ${files.toString()}`,
        {
          cause: error
        }
      );
    }
  }
}
export {
  updateLocalFiles
};
