import chalk from "chalk";
import { $ } from "execa";
import { Octokit } from "octokit";
import {
  skipSpinnerBlock,
  successSpinnerBlock,
  withSpinner
} from "./cli/spinners.js";
async function getOctokit(skipApi) {
  if (skipApi) {
    skipSpinnerBlock(`Skipping checking GitHub authentication.`);
    return void 0;
  }
  successSpinnerBlock(`Checking GitHub authentication.`);
  return await withSpinner(async () => {
    try {
      await $`gh auth status`;
    } catch (error) {
      console.error();
      console.error(chalk.red(error.message));
      console.error();
      throw new Error("GitHub authentication failed.");
    }
    const auth = (await $`gh auth token`).stdout.trim();
    return new Octokit({ auth });
  }, "fetching gh auth status");
}
export {
  getOctokit
};
